// Persistence of Vision RayTracer version 3.7 Scene description file
// File:        COLOR_CHART_WITH_LABELS.POV
// Description: An empty scene for displaying the different textures into.
// Date:        2022/01/07 - 21:10
// Author:      Anton Raves

// This scene has been developed at a 16 x 9 aspect ratio (widescreen) and should therefore
// be rendered at such a output ratio too! Currently the file size in the .ini-file has been set to
// 1920 x 1080, quite a nice size but also taking quite lot of time to render, so beware!

// This scene uses the Adobe Source Code Pro Semibold font, which you can / must download from here:
//
//      https://github.com/adobe-fonts/source-code-pro

#version 3.7;

#declare radio = 1;
#declare setting = 5;

#include "ultra_material.lib"
#include "ultra_library.lib"

camera {
  location  <62.5, 80, -250>
  direction 2*z
  up        y
  right     hdtv*x
  look_at   <62.5, 53, 0>
  rotate 	-5*y
}

#if (setting > 1)
  light_source { <700, 500, 0> color real_white area_light 50*y, 50*z, 5, 5 adaptive 0 jitter rotate 45*y }
  #declare nice = color real_white;
  #declare nice2 = color real_white;
  #declare grad_tex =
  texture {
    pigment { gradient y color_map { [ 0.0 color real_white ] [ 0.6 color nice2 ] } }
    finish { basic_finish }
    scale 200
  }
#else
  light_source { <700, 500, 0> color real_white media_interaction off rotate 45*y }
  #declare nice = color real_white;
  #declare nice2 = color real_white;
  #declare grad_tex =
  texture {
    pigment { gradient y color_map { [ 0.0 color real_white ] [ 0.6 color nice2 ] } }
    finish { basic_finish }
    scale 200
  }
#end

// the floor
box { <-800, -2, -800> <800, 0, 900> texture { pigment { color nice } } finish { basic_finish } }

// the "enclosing world"
box { <-750, -1, -750> <750, 750, 850> hollow texture { pigment { color real_white } } finish { basic_finish } }
// the background
union {
  box { <-800, -2, 849> <800, 800, 851> texture { finish { basic_finish } pigment { color nice2 } } }
  difference {
    box { <-800, 0, 649> <800, 200, 849> }
    cylinder { -805*x, 805*x, 200 translate <0, 200, 649> }
    texture { grad_tex }
  }
}

#macro example_brick(kleur_tex,finished,tekst_line_one,tekst_line_two,regel_x,regel_y)
  union {
    object { brick2x2(kleur_tex,1) interior { ior 1.5 } translate <-33+(regel_x*24), regel_y*19.2, regel_y*8> }
//    object { light_stick(kleur_tex) interior { ior 1.5 } translate <-29+(regel_x*24), (regel_y*19.2)+9.6, (regel_y*8)+4> }
    #if (finished = 1)
      object { plate1x1_round(bright_green_tex) translate <-29+(regel_x*24), 9.6+(regel_y*19.2), 4+(regel_y*8)> }
    #end
    #if (finished = 2)
      object { plate1x1_round(bright_red_tex) translate <-29+(regel_x*24), 9.6+(regel_y*19.2), 4+(regel_y*8)> }
    #end
    #if (tekst_line_one = "")
      box { <-3.9, 1, -3.95> <11.9, 4, -3.925> texture { white_tex } translate <-33+(regel_x*24), regel_y*19.2, regel_y*8> }
    #else
      box { <-3.9, 1, -3.95> <11.9, 7, -3.925> texture { white_tex } translate <-33+(regel_x*24), regel_y*19.2, regel_y*8> }
    #end
    text { ttf "SourceCodePro-Semibold.ttf", tekst_line_one, 0.2, 0 texture { black_tex } scale <2, 2, 0.25> translate <-36+(regel_x*24), 5+(regel_y*19.2), -4.1+(regel_y*8)> no_shadow }
    text { ttf "SourceCodePro-Semibold.ttf", tekst_line_two, 0.2, 0 texture { black_tex } scale <2, 2, 0.25> translate <-36+(regel_x*24), 2+(regel_y*19.2), -4.1+(regel_y*8)> no_shadow }
  }
#end

// the many textured bricks, aligned and labeled
union {
// First (or in some countries, the bottom) row left to right...
object { example_brick(transparent_yellow_tex,0,"Transparent","Yellow",0,0) }
object { example_brick(transparent_orange_tex,0,"Transparent","Orange",1,0) }
object { example_brick(transparent_fluorescent_reddish_orange_tex,0,"Transparent","Fluorescent Orange",2,0) }
object { example_brick(transparent_red_tex,0,"Transparent","Red",3,0) }
object { example_brick(transparent_medium_reddish_violet_tex,0,"Transparent Medium","Reddish Violet",4,0) }
//object { example_brick(transparent_bright_bluish_violet_tex,0,"Transparent","Bright Bluish Violet",5,0) }
object { example_brick(transparent_blue_tex,0,"Transparent","Blue",6,0) }
object { example_brick(transparent_fluorescent_blue_tex,0,"Transparent","Fluorescent Blue",7,0) }
object { example_brick(transparent_light_blue_tex,0,"Transparent","Light Blue",8,0) }
object { example_brick(transparent_green_tex,0,"Transparent","Green",9,0) }
object { example_brick(transparent_bright_green_tex,0,"Transparent","Bright Green",10,0) }
object { example_brick(transparent_fluorescent_green_tex,0,"Transparent","Fluorescent Green",11,0) }
//object { example_brick(transparent_brown_tex,0,"Transparent","Brown",12,0) }
// Second row
object { example_brick(white_tex,0,"","White",0,1) }
object { example_brick(light_stone_grey_tex,0,"Light","Stone Grey",1,1) }
object { example_brick(grey_tex,0,"","Grey",2,1) }
object { example_brick(medium_stone_grey_tex,0,"Medium","Stone Grey",3,1) }
object { example_brick(dark_grey_tex,0,"","Dark Grey",4,1) }
object { example_brick(dark_stone_grey_tex,0,"Dark","Stone Grey",5,1) }
object { example_brick(black_tex,0,"","Black",6,1) }
object { example_brick(silver_metallic_tex,0,"Silver","Metallic",7,1) }
object { example_brick(titanium_metallic_tex,0,"Titanium","Metallic",8,1) }
object { example_brick(chrome_tex,0,"","Chrome",9,1) }
object { example_brick(conductive_tex,2,"","Conductive",10,1) }
object { example_brick(copperish_tex,2,"Copper","Metallic",11,1) }
object { example_brick(r_yellow_tex,2,"Rubber","Yellow",12,1) }
// Third row
object { example_brick(light_bluish_green_tex,0,"Light Bluish","Green",0,2) }
object { example_brick(dark_brown_tex,0,"","Dark Brown",1,2) }
object { example_brick(sand_yellow_tex,0,"","Sand Yellow",2,2) }
object { example_brick(brick_yellow_tex,0,"","Brick Yellow",3,2) }
object { example_brick(reddish_brown_tex,0,"Reddish","Brown",4,2) }
object { example_brick(earth_orange_tex,0,"","Earth Orange",5,2) }
object { example_brick(dark_orange_tex,0,"","Dark Orange",6,2) }
object { example_brick(light_nougat_tex,0,"","Light Nougat",7,2) }
object { example_brick(nougat_tex,0,"","Nougat",8,2) }
object { example_brick(medium_nougat_tex,0,"Medium","Nougat",9,2) }
object { example_brick(warm_gold_tex,0,"","Warm Gold",10,2) }
object { example_brick(real_gold_tex,0,"","Real Gold",11,2) }
object { example_brick(gold_metallic_tex,0,"Gold","Metallic",12,2) }
object { example_brick(transparent_white_tex,0,"Transparent","White",13,2) }
// Fourth row
object { example_brick(aqua_tex,0,"","Aqua",0,3) }
object { example_brick(spring_yellowish_green_tex,0,"Spring","Yellowish Green",1,3) }
object { example_brick(earth_green_tex,0,"","Earth Green",2,3) }
object { example_brick(dark_green_tex,0,"","Dark Green",3,3) }
object { example_brick(sand_green_tex,0,"","Sand Green",4,3) }
object { example_brick(bright_green_tex,0,"","Bright Green",5,3) }
object { example_brick(olive_green_tex,0,"","Olive Green",6,3) }
object { example_brick(bright_yellowish_green_tex,0,"Bright","Yellowish Green",7,3) }
object { example_brick(bright_violet_tex,0,"Bright","Violet",8,3) }
object { example_brick(sand_violet_tex,0,"","Sand Violet",9,3) }
object { example_brick(sand_red_tex,0,"","Sand Red",10,3) }
object { example_brick(light_red_tex,0,"","Light Red",11,3) }
object { example_brick(light_reddish_violet_tex,0,"Light Reddish","Violet",12,3) }
object { example_brick(blue_gold_tex,0,"","Blue Gold",13,3) }
// Fifth row
object { example_brick(earth_blue_tex,0,"","Earth Blue",0,4) }
object { example_brick(sand_blue_tex,0,"","Sand Blue",1,4) }
object { example_brick(light_royal_blue_tex,0,"Light","Royal Blue",2,4) }
object { example_brick(medium_blue_tex,0,"","Medium Blue",3,4) }
object { example_brick(bright_blue_tex,0,"","Bright Blue",4,4) }
object { example_brick(medium_azure_tex,0,"","Medium Azure",5,4) }
object { example_brick(dark_azure_tex,0,"","Dark Azure",6,4) }
object { example_brick(bright_bluish_green_tex,0,"Bright","Bluish Green",7,4) }
object { example_brick(pastel_blue_tex,0,"","Pastel Blue",8,4) }
object { example_brick(transparent_old_clear_tex,2,"Transparent","Old Clear",9,4) }
object { example_brick(rubber_black_tex,0,"","Rubber Black",10,4) }
object { example_brick(rubber_black_with_bumps_tex,0,"Rubber Black","with bumps",11,4) }
object { example_brick(r_white_tex,2,"","Rubber White",12,4) }
object { example_brick(r_grey_tex,2,"","Rubber Grey",13,4) }
// Sixth row
object { example_brick(cool_yellow_tex,0,"","Cool Yellow",0,5) }
object { example_brick(light_yellow_tex,0,"","Light Yellow",1,5) }
object { example_brick(bright_yellow_tex,0,"Bright","Yellow",2,5) }
object { example_brick(flame_yellowish_orange_tex,0,"Flame","Yellowish Orange",3,5) }
object { example_brick(bright_yellowish_orange_tex,0,"Bright","Yellowish Orange",4,5) }
object { example_brick(bright_orange_tex,0,"Bright","Orange",5,5) }
object { example_brick(bright_red_tex,0,"","Bright Red",6,5) }
object { example_brick(new_dark_red_tex,0,"","New Dark Red",7,5) }
object { example_brick(bright_reddish_violet_tex,0,"Bright","Reddish Violet",8,5) }
object { example_brick(bright_purple_tex,0,"Bright","Purple",9,5) }
object { example_brick(light_purple_tex,0,"","Light Purple",10,5) }
object { example_brick(medium_lilac_tex,0,"","Medium Lilac",11,5) }
object { example_brick(medium_lavender_tex,0,"Medium","Lavender",12,5) }
object { example_brick(lavender_tex,0,"","Lavender",13,5) }
// Seventh row
object { example_brick(vibrant_yellow_tex,0,"Vibrant","Yellow",5,6) }
object { example_brick(vibrant_coral_tex,2,"Vibrant","Coral",6,6) }
object { example_brick(white_glow_tex,0,"","White Glow",12,6) }

// The one texture that can't have an interior... ;-)
object { brick2x2(transparent_clear_tex,1) translate <279, 115.2, 48> }
box { <-3.9, 1, -3.95> <11.9, 7, -3.925> texture { white_tex } translate <279, 115.2, 48> no_shadow }
text { ttf "SourceCodePro-Semibold.ttf", "Clear", 0.2, 0 texture { black_tex } scale <2, 2, 0.25> translate <278, 118.2, 48-4.1> no_shadow }
text { ttf "SourceCodePro-Semibold.ttf", "Transparent", 0.2, 0 texture { black_tex } scale <2, 2, 0.25> translate <278, 121.2, 48-4.1> no_shadow }

/* cleanup or remove...
object { brick2x2(blue2_tex,1) translate <48, 76.8, 32> }
box { <-3.9, 1, -3.95> <11.9, 4, -3.925> texture { white_tex } translate <48, 76.8, 32> no_shadow }
text { ttf "SourceCodePro-Semibold.ttf", "Blue2", 0.2, 0 texture { black_tex } scale <2, 2, 0.25> translate <45, 78.8, 26.9> no_shadow }

object { brick2x2(cyan_tex,1) translate <48, 57.6, 24> }
box { <-3.9, 1, -3.95> <11.9, 4, -3.925> texture { white_tex } translate <48, 57.6, 24> no_shadow }
text { ttf "SourceCodePro-Semibold.ttf", "Cyan", 0.2, 0 texture { black_tex } scale <2, 2, 0.25> translate <45, 59.6, 18.9> no_shadow }
object { example_brick(transparent_vizor_tex,2,"Transparent","Vizor",11,0) }

object { example_brick(dark_beige_tex,0,"","Dark Beige",11,1) }
object { example_brick(hologram_tex,2,"","Hologram",12,1) }
object { example_brick(r_brown_tex,2,"","Rubber Brown",11,4) }

*/

rotate -35*y
}
